#! /usr/bin/perl
#
# send-uucp.pl	create news batches from the outgoing files
#		This is a rewritten version from the send-uucp shell script
#		that is shipped with INN. Four times faster :-)
#		It's a little more verbose when creating the batches.
#
# Version:	@(#)send-uucp.pl  1.35  15-Apr-1998  miquels@cistron.nl
#
# Author:	Edvard Tuinder <ed@elm.net>
#
#		Copyright (C) 1994 Edvard Tuinder - ELM Consultancy B.V.
#		Copyright (C) 1995-1997 Miquel van Smoorenburg -
#					Cistron Internet Services
#
#		This program is free software; you can redistribute it and/or
#		modify it under the terms of the GNU General Public License
#		as published by the Free Software Foundation; either version
#		2 of the License, or (at your option) any later version.
#

require '/etc/news/innshellvars.pl';

$MAXSIZE = 150000;
$MAXJOBS = 200;


$Vers = 1.34;

$CF_FILE = '/etc/news/send-uucp.cf';
$BATCH_LOG = $inn'most_logs . '/news.admin';
$UUXFLAGS = '- -z -r -gd';
$PROGNAME='send-uucp';
$LOCK = $inn'locks."/LOCK.$PROGNAME";
$LOG = $inn'most_logs."/$PROGNAME.log";
$ENV{'PATH'}='/usr/lib/news/bin:/bin:/usr/bin:/sbin:/usr/sbin:/usr/lib/uucp';
$didlock = 0;

#
# Main section
#

unless (open (LOG, ">> $LOG")) {
  print "$PROGNAME: \[$$\] Couldn't open log file\n";
  exit 0;
}

$ct = localtime(time);
printf LOG "$PROGNAME: \[$$\] begin $ct\n";
unless (chdir ($inn'batch)) {
  &logit ("Can't access $inn'batch: $!");
  &do_end;
}

#
#	If there is a lockfile, print error and exit.
#
if (-e $LOCK) {
   unless (open(LOCK, $LOCK)) {
	&logit ("can't open $LOCK");
	close LOG;
	exit 0;
   }
   $_ = <LOCK>;
   s/[\r\n]+$//;
   &logit ("locked by $_");
   close LOCK;
   &do_end;
}

#
#	Create lockfile.
#	FIXME: this should be atomic.
#
unless (open(LOCK, "> $LOCK")) {
  &logit ("can't create lockfile $LOCK");
  &do_end;
}
print LOCK "$$";
close LOCK;
$didlock = 1;

#
#	Create the list of sites we're going to batch for.
#
if ($#ARGV != -1) {
  @LIST = @ARGV;
  $I = 0;
  while ($I <= $#LIST) {
	$Want_Site = $LIST[$I++];
	$ret = &read_cf;
	if ($ret == 1 || $#SITELIST == -1) {
		print "Site `$Want_Site' not found in config file. Ignored.\n";
	}
  }
} else {
  $Want_Site = '';
  $ret = &read_cf;
  if ($#SITELIST == -1 || $ret == 1) {
	&logit ("nothing to do.");
	&do_end;
  }
}


# Perform the real work
&run_site while ($Site = pop(@SITELIST));
&do_end;

# End of main section

sub logit {
  print LOG "$PROGNAME: \[$$\] @_\n";
  #print "$PROGNAME: \[$$\] $_[0]\n";
}

#
#	Remove lockfile and exit.
#
sub do_end {
  unlink $LOCK if ($didlock);
  $ct = localtime(time);
  printf LOG "$PROGNAME: \[$$\] end $ct\n";
  close LOG;
  exit 0;
}

#
#	Read config file.
#
sub read_cf {
  local (@TIME, $I, $hour);

  $hour = (localtime(time))[2];

  unless (open (CF, $CF_FILE)) {
	&logit ("can't open `$CF_FILE'");
	return 1;
  }
  while (<CF>) {
	chop;
	s/\s*#.*$//;
	unless (/^$/) {
		($Site, $Compress, $Size, $Time) = split (/\s+/);

		$Site = '' unless defined $Site;
		$Compress = '' unless defined $Compress;
		$Size = '' unless defined $Size;
		$Time = '' unless defined $Time;
 
		$Compress = $inn'compress if ($Compress eq "");
		$Compress =~ s/_/ /g;
		$Size = $MAXSIZE if ($Size eq "");

		if ($Want_Site && $Want_Site eq $Site) {
			push (@SITELIST, $Site);
			push (@COMPLIST, $Compress);
			push (@SIZELIST, $Size);
			close CF;
			return 0;
		}
		if ($Want_Site eq "") {
			if ($Time ne "") {
				@TIME = split (',', $Time);
				$I = 0;
				while ($I <= $#TIME) {
					if ($TIME[$I] == $hour) {
						push (@SITELIST, $Site);
						push (@COMPLIST, $Compress);
						push (@SIZELIST, $Size);
					}
					$I++;
				}
			} else {
				push (@SITELIST, $Site);
				push (@COMPLIST, $Compress);
				push (@SIZELIST, $Size);
			}
		}
	}
  }
  close CF;
  return 0;
}

#
#	Count number of jobs in the UUCP queue
#	for a given site ($Site)
#
sub count_jobs {
  my($cnt);

  return 0 unless open (Jobs, "uustat -s $Site|");

  $cnt = 0;
  $cnt++ while (<Jobs>);
  close(Jobs);
  $cnt;
}

#
#	Batch for one site.
#
sub run_site {
  my($jobs, $maxjobs);

  &logit ("checking site $Site");
  if (($jobs = &count_jobs ($Site)) >= $MAXJOBS) {
	&logit("too many jobs for $Site queued");
	# Don't forget to POP
	pop @COMPLIST; pop @SIZELIST;
	return;
  }
  $maxjobs = $MAXJOBS - $jobs;

  if (-f "$Site.work") {
	$err = '';
	$err = "$Site: $!" unless (open(OUT, ">>$Site"));
	$err = "$Site.work: $!" unless ($err ne '' || open(IN, "$Site.work"));
	if ($err ne '') {
		&logit($err);
		pop @COMPLIST; pop @SIZELIST;
		return;
	}
	while(<IN>) {
		print OUT;
	}
	close IN;
	close OUT;
  }

  rename ($Site, "$Site.work"); # May fail if $Site file doesn't exist
  system ("$inn'newsbin/ctlinnd -s -t120 flush $Site");
  if (! -s "$Site.work") {
	&logit ("no articles for $Site");
	# Don't forget to POP
	pop @COMPLIST; pop @SIZELIST;
	unlink ("$Site.work");
  } else {
	$Size = pop @SIZELIST;
	$Compress = pop @COMPLIST;
	if ($Compress ne "none") {
		system ("batcher -v -b $Size -N $maxjobs " .
		"-p\"(echo '#! cunbatch' ; exec $Compress ) | " .
		"uux $UUXFLAGS %s!rnews\" $Site $Site.work >> $BATCH_LOG");
	} else {
		system ("batcher -v -b $Size -N $maxjobs " .
		"-p\"uux $UUXFLAGS %s!rnews\" $Site $Site.work >> $BATCH_LOG");
	}
	## unlink ("$Site.work"); # `batcher' does this.
	&logit ("batched for $Site");
  }
}
